API docs for “spamfighter.api.message.firewall.FirewallCommand”

# Class s.a.m.f.FirewallCommand(DomainedCommand):

Part of spamfighter.api.message.firewall View Source View In Hierarchy

Known subclasses: spamfighter.api.message.firewall.FirewallRulesCheckCommand, spamfighter.api.message.firewall.FirewallRulesGetCommand, spamfighter.api.message.firewall.FirewallRulesSetCommand, spamfighter.api.message.test.test_firewall.FakeFirewallCommand

Базовая команда работы с firewall

Instance Variables | firewall | найденный в домене firewall (type: `IMessageFirewall` )

Method | init | Дополнительный метод, может переопределяться в потомках для выполнения процедуры

def init(self): (source)
Дополнительный метод, может переопределяться в потомках для выполнения процедуры дополнительной предварительной инициализации.